@@ -8,7 +8,7 @@ def NCLS(starts, ends, ids):
     if isinstance(starts, list) or "pandas" in str(type(starts)):
         starts, ends, ids = [np.array(s) for s in [starts, ends, ids]]
 
-    ids = np.astype(np.int64)
+    ids = ids.astype(np.int64)
     if starts.dtype == np.int64:
         return NCLS64(starts, ends.astype(np.int64), ids)
     elif starts.dtype == np.int32:
